# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

import typing_extensions

from ..types.observability_status import ObservabilityStatus
from .chat_message_with_tool_call import ChatMessageWithToolCallParams
from .config_response import ConfigResponseParams
from .feedback_response import FeedbackResponseParams
from .metric_value_response import MetricValueResponseParams
from .src_external_app_models_v_4_log_log_response_judgment import SrcExternalAppModelsV4LogLogResponseJudgmentParams
from .src_external_app_models_v_4_log_log_response_tool_choice import (
    SrcExternalAppModelsV4LogLogResponseToolChoiceParams,
)
from .tool_result_response import ToolResultResponseParams

if typing.TYPE_CHECKING:
    from .evaluation_result_response import EvaluationResultResponseParams


class SrcExternalAppModelsV4LogLogResponseParams(typing_extensions.TypedDict):
    """
    Request model for logging a datapoint.
    """

    project: typing_extensions.NotRequired[str]
    """
    The name of the project associated with this log
    """

    project_id: typing_extensions.NotRequired[str]
    """
    The unique ID of the project associated with this log.
    """

    session_id: typing_extensions.NotRequired[str]
    """
    ID of the session to associate the datapoint.
    """

    session_reference_id: typing_extensions.NotRequired[str]
    """
    A unique string identifying the session to associate the datapoint to. Allows you to log multiple datapoints to a session (using an ID kept by your internal systems) by passing the same `session_reference_id` in subsequent log requests. Specify at most one of this or `session_id`.
    """

    parent_id: typing_extensions.NotRequired[str]
    """
    ID associated to the parent datapoint in a session.
    """

    parent_reference_id: typing_extensions.NotRequired[str]
    """
    A unique string identifying the previously-logged parent datapoint in a session. Allows you to log nested datapoints with your internal system IDs by passing the same reference ID as `parent_id` in a prior log request. Specify at most one of this or `parent_id`. Note that this cannot refer to a datapoint being logged in the same request.
    """

    inputs: typing_extensions.NotRequired[typing.Dict[str, typing.Any]]
    """
    The inputs passed to the prompt template.
    """

    source: typing_extensions.NotRequired[str]
    """
    Identifies where the model was called from.
    """

    metadata: typing_extensions.NotRequired[typing.Dict[str, typing.Any]]
    """
    Any additional metadata to record.
    """

    save: typing_extensions.NotRequired[bool]
    """
    Whether the request/response payloads will be stored on Humanloop.
    """

    source_datapoint_id: typing_extensions.NotRequired[str]
    """
    ID of the source datapoint if this is a log derived from a datapoint in a dataset.
    """

    id: str
    """
    String ID of logged datapoint. Starts with `data_`.
    """

    reference_id: typing_extensions.NotRequired[str]
    """
    Unique user-provided string identifying the datapoint.
    """

    trial_id: typing_extensions.NotRequired[str]
    """
    Unique ID of an experiment trial to associate to the log.
    """

    messages: typing_extensions.NotRequired[typing.Sequence[ChatMessageWithToolCallParams]]
    """
    The messages passed to the to provider chat endpoint.
    """

    output: typing_extensions.NotRequired[str]
    """
    Generated output from your model for the provided inputs. Can be `None` if logging an error, or if logging a parent datapoint with the intention to populate it later
    """

    judgment: typing_extensions.NotRequired[SrcExternalAppModelsV4LogLogResponseJudgmentParams]
    config_id: typing_extensions.NotRequired[str]
    """
    Unique ID of a config to associate to the log.
    """

    config: ConfigResponseParams
    environment: typing_extensions.NotRequired[str]
    """
    The environment name used to create the log.
    """

    feedback: typing_extensions.NotRequired[typing.Sequence[FeedbackResponseParams]]
    created_at: typing_extensions.NotRequired[dt.datetime]
    """
    User defined timestamp for when the log was created.
    """

    error: typing_extensions.NotRequired[str]
    """
    Error message if the log is an error.
    """

    duration: typing_extensions.NotRequired[float]
    """
    Duration of the logged event in seconds.
    """

    output_message: typing_extensions.NotRequired[ChatMessageWithToolCallParams]
    """
    The message returned by the provider.
    """

    prompt_tokens: typing_extensions.NotRequired[int]
    """
    Number of tokens in the prompt used to generate the output.
    """

    output_tokens: typing_extensions.NotRequired[int]
    """
    Number of tokens in the output generated by the model.
    """

    prompt_cost: typing_extensions.NotRequired[float]
    """
    Cost in dollars associated to the tokens in the prompt.
    """

    output_cost: typing_extensions.NotRequired[float]
    """
    Cost in dollars associated to the tokens in the output.
    """

    provider_request: typing_extensions.NotRequired[typing.Dict[str, typing.Any]]
    """
    Raw request sent to provider.
    """

    provider_response: typing_extensions.NotRequired[typing.Dict[str, typing.Any]]
    """
    Raw response received the provider.
    """

    user: typing_extensions.NotRequired[str]
    """
    User email address provided when creating the datapoint.
    """

    provider_latency: typing_extensions.NotRequired[float]
    """
    Latency of provider response.
    """

    tokens: typing_extensions.NotRequired[int]
    """
    Total number of tokens in the prompt and output.
    """

    raw_output: typing_extensions.NotRequired[str]
    """
    Raw output from the provider.
    """

    finish_reason: typing_extensions.NotRequired[str]
    """
    Reason the generation finished.
    """

    metric_values: typing_extensions.NotRequired[typing.Sequence[MetricValueResponseParams]]
    tools: typing_extensions.NotRequired[typing.Sequence[ToolResultResponseParams]]
    tool_choice: typing_extensions.NotRequired[SrcExternalAppModelsV4LogLogResponseToolChoiceParams]
    """
    Controls how the model uses tools. The following options are supported: 'none' forces the model to not call a tool; the default when no tools are provided as part of the model config. 'auto' the model can decide to call one of the provided tools; the default when tools are provided as part of the model config. Providing {'type': 'function', 'function': {name': <TOOL_NAME>}} forces the model to use the named function.
    """

    evaluation_results: typing.Sequence["EvaluationResultResponseParams"]
    observability_status: ObservabilityStatus
    updated_at: dt.datetime
    batch_ids: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    List of batch IDs the log belongs to.
    """
